import { ControllerDefinition } from './controller/ControllerDefinition';
import { ErrorHandlerFunction } from './errors/ControllerErrorHandler';
import { ParameterDefinition } from './parameter/ParameterDefinition';
import { RouteDefinition } from './routes/RouteDefinition';
import { RouteModificator } from './routes/RouteModificator';
/**
 * Helper class that is used to register giuseppe - stuff to the specific controllers.
 *
 * @export
 * @class GiuseppeRegistrar
 */
export declare class GiuseppeRegistrar {
    /**
     * List of controller definitions.
     *
     * @type {ControllerDefinition[]}
     * @memberof GiuseppeRegistrar
     */
    readonly controller: ControllerDefinition[];
    /**
     * Registeres a controller definition within the register (list of controllers).
     *
     * @param {ControllerDefinition} controller
     * @memberof GiuseppeRegistrar
     */
    registerController(controller: ControllerDefinition): void;
    /**
     * Register a route to a controllers metadata.
     *
     * @param {Object} controller
     * @param {RouteDefinition} route
     * @memberof GiuseppeRegistrar
     */
    registerRoute(controller: Object, route: RouteDefinition): void;
    /**
     * Register a modificator for a route of a controller.
     *
     * @param {Object} controller
     * @param {string} routeName
     * @param {RouteModificator} modificator
     * @memberof GiuseppeRegistrar
     */
    registerRouteModificator(controller: Object, routeName: string, modificator: RouteModificator): void;
    /**
     * Register a parameter for a route of a controller.
     *
     * @param {Object} controller
     * @param {string} routeName
     * @param {ParameterDefinition} parameter
     * @memberof GiuseppeRegistrar
     */
    registerParameter(controller: Object, routeName: string, parameter: ParameterDefinition): void;
    /**
     * Register an error handler for a given error type for a controller.
     *
     * @param {Object} controller
     * @param {ErrorHandlerFunction<Error>} handler
     * @param {Function[]} errors
     * @memberof GiuseppeRegistrar
     */
    registerErrorHandler(controller: Object, handler: ErrorHandlerFunction<Error>, errors: Function[]): void;
}
