/// <reference types="express" />
import 'reflect-metadata';
import { Response } from 'express';
import { ReturnType } from './routes/ReturnType';
/**
 * This handler is registered within the giuseppe core and holds all registered return type handlers. All those
 * {@link ReturnType} are than checked when a return value is given to the handler. If no matching handler is found
 * the default handler is taken. If even that isn't found, an error is thrown.
 *
 * @export
 * @class ReturnTypeHandler
 */
export declare class ReturnTypeHandler {
    private returnTypes;
    constructor(types: ReturnType<any>[]);
    /**
     * Handles the response for a given value. Searches in the handlers for the correct return type handler. If no matching
     * handler is found, the `default` handler is used. And if no default is registered (or was overwritten with undefined)
     * an error is thrown.
     *
     * @param {*} value
     * @param {Response} response
     * @throws {NoReturnValueHandlerFoundError} One handler must be there to handle the value.
     * @memberof ReturnTypeHandler
     */
    handleValue(value: any, response: Response): void;
}
