"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const GiuseppeApiController_1 = require("./controller/GiuseppeApiController");
const Body_1 = require("./parameters/Body");
const Cookie_1 = require("./parameters/Cookie");
const Header_1 = require("./parameters/Header");
const Query_1 = require("./parameters/Query");
const UrlParam_1 = require("./parameters/UrlParam");
const JsonDefaultReturnType_1 = require("./returnTypes/JsonDefaultReturnType");
const Delete_1 = require("./routes/Delete");
const Get_1 = require("./routes/Get");
const Head_1 = require("./routes/Head");
const Post_1 = require("./routes/Post");
const Put_1 = require("./routes/Put");
/**
 * Core plugin of giuseppe. Contains all the basic routes, controller and parameter.
 *
 * @export
 * @class GiuseppeCorePlugin
 * @implements {GiuseppePlugin}
 */
class GiuseppeCorePlugin {
    constructor() {
        this.returnTypeHandler = [];
        this.controllerDefinitions = [];
        this.routeDefinitions = [];
        this.routeModificators = null;
        this.parameterDefinitions = [];
    }
    get name() {
        return this.constructor.name;
    }
    initialize() {
        this.returnTypeHandler.push(new JsonDefaultReturnType_1.JsonDefaultReturnType());
        this.controllerDefinitions.push(GiuseppeApiController_1.GiuseppeApiController);
        this.routeDefinitions.push(Get_1.GiuseppeGetRoute);
        this.routeDefinitions.push(Post_1.GiuseppePostRoute);
        this.routeDefinitions.push(Put_1.GiuseppePutRoute);
        this.routeDefinitions.push(Delete_1.GiuseppeDeleteRoute);
        this.routeDefinitions.push(Head_1.GiuseppeHeadRoute);
        this.parameterDefinitions.push(Query_1.GiuseppeQueryParameter);
        this.parameterDefinitions.push(UrlParam_1.GiuseppeUrlParameter);
        this.parameterDefinitions.push(Body_1.GiuseppeBodyParameter);
        this.parameterDefinitions.push(Header_1.GiuseppeHeaderParameter);
        this.parameterDefinitions.push(Cookie_1.GiuseppeCookieParameter);
    }
}
exports.GiuseppeCorePlugin = GiuseppeCorePlugin;
