/// <reference types="express" />
import 'reflect-metadata';
import { Request } from 'express';
import { GiuseppeBaseParameter } from './GiuseppeBaseParameter';
import { ParameterFactory, ParameterValidator } from './ParameterAdditions';
/**
 * Parameter decorator. Creates a parameter decorator that is registered on that route. Can
 * contain a type factory and multiple validators.
 *
 * @export
 * @param {{ validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{ validator, factory } = {}]
 * @returns {ParameterDecorator}
 */
export declare function Body({required, validator, factory}?: {
    required?: boolean;
    validator?: ParameterValidator;
    factory?: ParameterFactory<any>;
}): ParameterDecorator;
/**
 * Default core body parameter of giuseppe. Injects Request.body into the route.
 *
 * @export
 * @class GiuseppeBodyParameter
 * @extends {GiuseppeBaseParameter}
 */
export declare class GiuseppeBodyParameter extends GiuseppeBaseParameter {
    constructor(type: Function, index: number, required?: boolean, validator?: ParameterValidator, factory?: ParameterFactory<any>);
    protected getRawValue(request: Request): any;
}
