"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Giuseppe_1 = require("../../Giuseppe");
const ControllerMetadata_1 = require("../../utilities/ControllerMetadata");
const GiuseppeBaseParameter_1 = require("./GiuseppeBaseParameter");
/**
 * Parameter decorator. Creates a parameter decorator that is registered on that route. Can
 * contain a type factory and multiple validators.
 *
 * @export
 * @param {{ validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{ validator, factory } = {}]
 * @returns {ParameterDecorator}
 */
function Body({ required, validator, factory, } = {}) {
    return (target, propertyKey, parameterIndex) => Giuseppe_1.Giuseppe.registrar.registerParameter(target, propertyKey, new GiuseppeBodyParameter(new ControllerMetadata_1.ControllerMetadata(target).parameterTypes(propertyKey)[parameterIndex], parameterIndex, required, validator, factory));
}
exports.Body = Body;
/**
 * Default core body parameter of giuseppe. Injects Request.body into the route.
 *
 * @export
 * @class GiuseppeBodyParameter
 * @extends {GiuseppeBaseParameter}
 */
class GiuseppeBodyParameter extends GiuseppeBaseParameter_1.GiuseppeBaseParameter {
    constructor(type, index, required, validator, factory) {
        super('body', type, index, required, validator, factory);
    }
    getRawValue(request) {
        return request.body;
    }
}
exports.GiuseppeBodyParameter = GiuseppeBodyParameter;
