/// <reference types="express" />
import 'reflect-metadata';
import { Request } from 'express';
import { GiuseppeBaseParameter } from './GiuseppeBaseParameter';
import { ParameterFactory, ParameterValidator } from './ParameterAdditions';
/**
 * Parameter decorator. Creates a parameter definition that injects a specific cookie from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name Name of the cookie.
 * @param {{ required?: boolean, validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         required,
 *         validator,
 *         factory,
 *     }={}] Configuration object for the cookie parameter.
 * @returns {ParameterDecorator}
 */
export declare function Cookie(name: string, {required, validator, factory}?: {
    required?: boolean;
    validator?: ParameterValidator;
    factory?: ParameterFactory<any>;
}): ParameterDecorator;
/**
 * Default core cookie parameter of giuseppe. Injects the value of a specific cookie from the request.
 *
 * @export
 * @class GiuseppeCookieParameter
 * @extends {GiuseppeBaseParameter}
 */
export declare class GiuseppeCookieParameter extends GiuseppeBaseParameter {
    protected getRawValue(request: Request): any;
}
