"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Giuseppe_1 = require("../../Giuseppe");
const ControllerMetadata_1 = require("../../utilities/ControllerMetadata");
const GiuseppeBaseParameter_1 = require("./GiuseppeBaseParameter");
/**
 * Class that splits cookie values into their specific parts.
 *
 * @class CookieHelper
 */
class CookieHelper {
    constructor(value) {
        const split = value.split('=');
        this.name = split[0];
        this.value = split[1];
    }
}
/**
 * Parameter decorator. Creates a parameter definition that injects a specific cookie from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name Name of the cookie.
 * @param {{ required?: boolean, validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         required,
 *         validator,
 *         factory,
 *     }={}] Configuration object for the cookie parameter.
 * @returns {ParameterDecorator}
 */
function Cookie(name, { required, validator, factory, } = {}) {
    return (target, propertyKey, parameterIndex) => Giuseppe_1.Giuseppe.registrar.registerParameter(target, propertyKey, new GiuseppeCookieParameter(name, new ControllerMetadata_1.ControllerMetadata(target).parameterTypes(propertyKey)[parameterIndex], parameterIndex, required, validator, factory));
}
exports.Cookie = Cookie;
/**
 * Default core cookie parameter of giuseppe. Injects the value of a specific cookie from the request.
 *
 * @export
 * @class GiuseppeCookieParameter
 * @extends {GiuseppeBaseParameter}
 */
class GiuseppeCookieParameter extends GiuseppeBaseParameter_1.GiuseppeBaseParameter {
    getRawValue(request) {
        const cookies = request.get('cookie');
        if (!cookies) {
            return undefined;
        }
        const cookie = cookies
            .split(';')
            .map(o => new CookieHelper(o.trim()))
            .filter(o => o.name === this.name)[0];
        return cookie ? cookie.value : undefined;
    }
}
exports.GiuseppeCookieParameter = GiuseppeCookieParameter;
