/// <reference types="express" />
import 'reflect-metadata';
import { Request } from 'express';
import { ParameterDefinition } from '../../parameter/ParameterDefinition';
import { ParameterFactory } from './ParameterAdditions';
/**
 * Giuseppe base parameter class. Is used for all core parameters (like cookie or body) to generalize
 * some logic.
 *
 * @export
 * @abstract
 * @class GiuseppeBaseParameter
 * @implements {ParameterDefinition}
 */
export declare abstract class GiuseppeBaseParameter implements ParameterDefinition {
    readonly name: string;
    readonly type: Function;
    readonly index: number;
    protected readonly required: boolean | undefined;
    protected readonly validator: ((value: any) => boolean) | ((value: any) => boolean)[] | undefined;
    protected readonly factory: ParameterFactory<any> | undefined;
    readonly canHandleResponse: boolean;
    constructor(name: string, type: Function, index: number, required?: boolean | undefined, validator?: ((value: any) => boolean) | ((value: any) => boolean)[] | undefined, factory?: ParameterFactory<any> | undefined);
    getValue(request: Request): any;
    protected abstract getRawValue(request: Request): any;
    protected parseValue(raw: any): any;
    protected validateValue(parsed: any): void;
}
