/// <reference types="express" />
import 'reflect-metadata';
import { Request } from 'express';
import { GiuseppeBaseParameter } from './GiuseppeBaseParameter';
import { ParameterFactory, ParameterValidator } from './ParameterAdditions';
/**
 * Parameter decorator. Creates a parameter definition that injects a specific header value from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name
 * @param {{ required?: boolean, validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         required,
 *         validator,
 *         factory,
 *     }={}]
 * @returns {ParameterDecorator}
 */
export declare function Header(name: string, {required, validator, factory}?: {
    required?: boolean;
    validator?: ParameterValidator;
    factory?: ParameterFactory<any>;
}): ParameterDecorator;
/**
 * Default core header parameter of giuseppe. Injects a specific header value into the route.
 *
 * @export
 * @class GiuseppeHeaderParameter
 * @extends {GiuseppeBaseParameter}
 */
export declare class GiuseppeHeaderParameter extends GiuseppeBaseParameter {
    protected getRawValue(request: Request): any;
}
