"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Giuseppe_1 = require("../../Giuseppe");
const ControllerMetadata_1 = require("../../utilities/ControllerMetadata");
const GiuseppeBaseParameter_1 = require("./GiuseppeBaseParameter");
/**
 * Parameter decorator. Creates a parameter definition that injects a specific header value from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name
 * @param {{ required?: boolean, validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         required,
 *         validator,
 *         factory,
 *     }={}]
 * @returns {ParameterDecorator}
 */
function Header(name, { required, validator, factory, } = {}) {
    return (target, propertyKey, parameterIndex) => Giuseppe_1.Giuseppe.registrar.registerParameter(target, propertyKey, new GiuseppeHeaderParameter(name, new ControllerMetadata_1.ControllerMetadata(target).parameterTypes(propertyKey)[parameterIndex], parameterIndex, required, validator, factory));
}
exports.Header = Header;
/**
 * Default core header parameter of giuseppe. Injects a specific header value into the route.
 *
 * @export
 * @class GiuseppeHeaderParameter
 * @extends {GiuseppeBaseParameter}
 */
class GiuseppeHeaderParameter extends GiuseppeBaseParameter_1.GiuseppeBaseParameter {
    getRawValue(request) {
        return request.get(this.name);
    }
}
exports.GiuseppeHeaderParameter = GiuseppeHeaderParameter;
