"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Giuseppe_1 = require("../../Giuseppe");
const ControllerMetadata_1 = require("../../utilities/ControllerMetadata");
const GiuseppeBaseParameter_1 = require("./GiuseppeBaseParameter");
/**
 * @typedef QueryConfigObject
 
 * @property {string | string[]} [alias]
 * @property {boolean} [required]
 * @property {ParameterValidator} [validator]
 * @property {ParameterFactory<any>} [factory]
 */
/**
 * Parameter decorator. Creates a parameter definition that injects a query parameter value from the request.
 * Can contain validators and a factory if the value is complex. If an alias is defined, the alias(es)
 * will be used to determine a value other than the given name.
 *
 * @export
 * @param {string} name
 * @param {QueryConfigObject} [{alias, required, validator, factory}={}]
 * @returns {ParameterDecorator}
 */
function Query(name, { alias, required, validator, factory, } = {}) {
    return (target, propertyKey, parameterIndex) => Giuseppe_1.Giuseppe.registrar.registerParameter(target, propertyKey, new GiuseppeQueryParameter(name, new ControllerMetadata_1.ControllerMetadata(target).parameterTypes(propertyKey)[parameterIndex], parameterIndex, required, validator, factory, alias));
}
exports.Query = Query;
/**
 * Default core query parameter of giuseppe. Does inject a query parameter from the request into the route.
 * Can contain an alias that the query parameter can be named with.
 *
 * @export
 * @class GiuseppeQueryParameter
 * @extends {GiuseppeBaseParameter}
 */
class GiuseppeQueryParameter extends GiuseppeBaseParameter_1.GiuseppeBaseParameter {
    constructor(name, type, index, required, validator, factory, alias) {
        super(name, type, index, required, validator, factory);
        this.alias = alias;
    }
    getRawValue(request) {
        if (!this.alias) {
            return request.query[this.name];
        }
        let aliases = !Array.isArray(this.alias) ? [this.alias] : this.alias;
        aliases = aliases.map((a) => request.query[a]).filter(Boolean);
        return aliases[0] || request.query[this.name];
    }
}
exports.GiuseppeQueryParameter = GiuseppeQueryParameter;
