/// <reference types="express" />
import 'reflect-metadata';
import { Request } from 'express';
import { GiuseppeBaseParameter } from './GiuseppeBaseParameter';
import { ParameterFactory, ParameterValidator } from './ParameterAdditions';
/**
 * Parameter decorator. Creates a parameter definition that injects a url parameter value from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name
 * @param {{ validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         validator,
 *         factory,
 *     }={}]
 * @returns {ParameterDecorator}
 */
export declare function UrlParam(name: string, {validator, factory}?: {
    validator?: ParameterValidator;
    factory?: ParameterFactory<any>;
}): ParameterDecorator;
/**
 * Default core url parameter of giuseppe. Injects a given url parameter for a route.
 *
 * @export
 * @class GiuseppeUrlParameter
 * @extends {GiuseppeBaseParameter}
 */
export declare class GiuseppeUrlParameter extends GiuseppeBaseParameter {
    constructor(name: string, type: Function, index: number, validator?: ParameterValidator, factory?: ParameterFactory<any>);
    protected getRawValue(request: Request): any;
}
