"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Giuseppe_1 = require("../../Giuseppe");
const ControllerMetadata_1 = require("../../utilities/ControllerMetadata");
const GiuseppeBaseParameter_1 = require("./GiuseppeBaseParameter");
/**
 * Parameter decorator. Creates a parameter definition that injects a url parameter value from the request.
 * Can contain validators and a factory if the value is complex.
 *
 * @export
 * @param {string} name
 * @param {{ validator?: ParameterValidator, factory?: ParameterFactory<any> }} [{
 *         validator,
 *         factory,
 *     }={}]
 * @returns {ParameterDecorator}
 */
function UrlParam(name, { validator, factory, } = {}) {
    return (target, propertyKey, parameterIndex) => Giuseppe_1.Giuseppe.registrar.registerParameter(target, propertyKey, new GiuseppeUrlParameter(name, new ControllerMetadata_1.ControllerMetadata(target).parameterTypes(propertyKey)[parameterIndex], parameterIndex, validator, factory));
}
exports.UrlParam = UrlParam;
/**
 * Default core url parameter of giuseppe. Injects a given url parameter for a route.
 *
 * @export
 * @class GiuseppeUrlParameter
 * @extends {GiuseppeBaseParameter}
 */
class GiuseppeUrlParameter extends GiuseppeBaseParameter_1.GiuseppeBaseParameter {
    constructor(name, type, index, validator, factory) {
        super(name, type, index, true, validator, factory);
    }
    getRawValue(request) {
        return request.params[this.name];
    }
}
exports.GiuseppeUrlParameter = GiuseppeUrlParameter;
