"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const httpStatus = require("http-status");
/**
 * Definition of the json headers.
 */
const jsonHeader = {
    'Content-Type': 'application/json',
};
/**
 * Return type handler for the default return values. Does convert everything into JSON and returns the stringified
 * value to giuseppe and therefore express. If no value is provided, httpStatus.NO_CONTENT (204) is set, otherwise OK (200).
 *
 * @export
 * @class JsonDefaultReturnType
 * @implements {ReturnType<any>}
 */
class JsonDefaultReturnType {
    constructor() {
        this.type = 'default';
    }
    getHeaders() {
        return jsonHeader;
    }
    getStatus(value) {
        if (value === undefined || value === null) {
            return httpStatus.NO_CONTENT;
        }
        return httpStatus.OK;
    }
    getValue(value) {
        return JSON.stringify(value);
    }
}
exports.JsonDefaultReturnType = JsonDefaultReturnType;
