"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const __1 = require("../..");
const RouteDefinition_1 = require("../../routes/RouteDefinition");
const GiuseppeBaseRoute_1 = require("./GiuseppeBaseRoute");
/**
 * Route decorator. Creates a route definition that reacts to a delete request.
 * Can define one or multiple middlewares that are registered for that route. Also, a route name can be specified
 * that creates the url for express.
 *
 * @export
 * @param {(string | RequestHandler)} [routeOrMiddleware] Either a string that represents the url for this route, or
 *                                                        an optional middleware if no specific route is needed.
 * @param {...RequestHandler[]} middlewares Other middlewares that are used for this route.
 * @returns {FunctionMethodDecorator}
 */
function Delete(routeOrMiddleware, ...middlewares) {
    const route = routeOrMiddleware && typeof routeOrMiddleware === 'string' ? routeOrMiddleware : '';
    if (routeOrMiddleware && typeof routeOrMiddleware === 'function') {
        middlewares.unshift(routeOrMiddleware);
    }
    return (target, _, descriptor) => {
        if (!descriptor.value) {
            throw new TypeError(`Function is undefined in route ${route}`);
        }
        __1.Giuseppe.registrar.registerRoute(target, new GiuseppeDeleteRoute(descriptor.value, route, middlewares));
    };
}
exports.Delete = Delete;
/**
 * Default core delete route of giuseppe. Reacts to http.DELETE.
 *
 * @export
 * @class GiuseppeDeleteRoute
 * @extends {GiuseppeBaseRoute}
 */
class GiuseppeDeleteRoute extends GiuseppeBaseRoute_1.GiuseppeBaseRoute {
    constructor(routeFunction, route = '', middlewares = []) {
        super(RouteDefinition_1.HttpMethod.delete, routeFunction, route, middlewares);
    }
}
exports.GiuseppeDeleteRoute = GiuseppeDeleteRoute;
