import 'reflect-metadata';
import { ErrorHandlerFunction } from './ControllerErrorHandler';
/**
 * Reflect metadata key for error handler manager.
 * @type {string}
 */
export declare const ERRORHANDLER_KEY = "giuseppe:errorHandler";
/**
 * Type for giuseppes error handler decorators.
 * Does generically restrain the MethodDecorator to error handler functions only.
 */
export declare type ErrorHandlerMethodDecorator = (target: Object, _: string | symbol, descriptor: TypedPropertyDescriptor<ErrorHandlerFunction<Error>>) => void;
/**
 * Errorhandler decorator; decorates the given function as an error handler for the current controller.
 * You can specify various errors in the open parameter list. The handler is registered for the given error types,
 * and is only called if the thrown error matches the registered type. If errors are omitted, the handler will be
 * registered as 'default' and is called if no other specialized handler matches the thrown error.
 *
 * @param {...Error[]} errors List of error classes to register to.
 * @returns {(any, string, PropertyDescriptor) => void} Decorator for the class function.
 */
export declare function ErrorHandler(...errors: Function[]): ErrorHandlerMethodDecorator;
